@@ -12,7 +12,7 @@ use Scalar::Util qw/reftype/;
 use namespace::autoclean;
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.04000';
+our $VERSION = '3.04001';
 
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
@@ -24,6 +24,8 @@ has username        => ( traits => [qw/MooseX::MultiInitArg::Trait/],
 has password        => ( traits => [qw/MooseX::MultiInitArg::Trait/],
                          isa => 'Str', is => 'rw', predicate => 'has_password',
                          init_args => [qw/pass/] );
+has ssl             => ( isa => 'Bool', is => 'ro', default => 0 );
+has netrc           => ( isa => 'Bool', is => 'ro', default => 0 );
 has useragent       => ( isa => 'Str', is => 'ro', default => "Net::Twitter/$VERSION (Perl)" );
 has source          => ( isa => 'Str', is => 'ro', default => 'twitterpm' );
 has ua              => ( isa => 'Object', is => 'rw' );
@@ -31,6 +33,11 @@ has clientname      => ( isa => 'Str', is => 'ro', default => 'Perl Net::Twitter
 has clientver       => ( isa => 'Str', is => 'ro', default => $VERSION );
 has clienturl       => ( isa => 'Str', is => 'ro', default => 'http://search.cpan.org/dist/Net-Twitter/' );
 has _base_url       => ( is => 'rw' ); ### keeps role composition from bitching ??
+has _json_handler   => (
+    is      => 'rw',
+    default => sub { JSON::Any->new(uft8 => 1) },
+    handles => { _from_json => 'from_json' },
+);
 
 sub BUILD {
     my $self = shift;
@@ -38,6 +45,20 @@ sub BUILD {
     eval "use " . $self->useragent_class;
     croak $@ if $@;
 
+    $self->{apiurl} =~ s/http/https/ if $self->ssl;
+
+    if ( $self->netrc ) {
+        require Net::Netrc;
+
+        my $host = URI->new($self->apiurl)->host;
+        my $nrc  = Net::Netrc->lookup($host)
+            || croak "No .netrc entry for $host";
+
+        my ($user, $pass) = $nrc->lpa;
+        $self->username($user);
+        $self->password($pass);
+    }
+
     $self->ua($self->useragent_class->new(%{$self->useragent_args}));
     $self->ua->agent($self->useragent);
     $self->ua->default_header('X-Twitter-Client'         => $self->clientname);
@@ -79,12 +100,6 @@ sub _authenticated_request {
     return $self->ua->request($msg);
 }
 
-sub _from_json {
-    my ($self, $json) = @_;
-
-    return eval { JSON::Any->from_json($json) };
-}
-
 # By default, Net::Twitter does not inflate objects, so just return the
 # hashref, untouched. This is really just a hook for Role::InflateObjects.
 sub _inflate_objects { return $_[1] }
@@ -97,7 +112,7 @@ sub _parse_result {
     my $content = $res->content;
     $content =~ s/^"(true|false)"$/$1/;
 
-    my $obj = $self->_from_json($content);
+    my $obj = eval { $self->_from_json($content) };
 
     # inflate the twitter object(s) if possible
     $self->_inflate_objects($obj);
